@@ -20,7 +20,7 @@ use PPIx::QuoteLike::Utils qw{
 
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.021_01';
+our $VERSION = '0.022_01';
 
 sub ppi {
     my ( $self ) = @_;
@@ -131,16 +131,18 @@ C<'${foo}'>, but the content of the C<PPI::Document> will be C<'$foo'>.
 
  say "Interpolates $_" for $elem->variables();
 
-This convenience method returns all interpolated variables. Each is
-returned only once, and they are returned in no particular order.
-
 B<NOTE> that this method is discouraged, and may well be deprecated and
-removed. My problem with it is that it returns variable names rather
-than L<PPI::Element|PPI::Element> objects, leaving you no idea how the
-variables are used. It was originally written for the benefit of
+removed. I have two problems with it. The first is that it returns
+variable names rather than L<PPI::Element|PPI::Element> objects, leaving
+you no idea how the variables are used. The second is that it does not
+properly handle things like C<"${^CAPTURE[0]}">, and it seems infeasible
+to make it do so. It was originally written for the benefit of
 L<Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter|Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter>,
 but has proven inadequate to that policy's needs.
 
+This convenience method returns all interpolated variables. Each is
+returned only once, and they are returned in no particular order.
+
 =head1 SEE ALSO
 
 L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
